import { RectanglesOutput } from './rectangles.interfaces';
import { LogLevel } from '../helpers/options.interface';
import { Folders } from '../base.interface';
export interface ResizeDimensions {
    bottom?: number;
    left?: number;
    right?: number;
    top?: number;
}
export interface ImageCompareOptions {
    devicePixelRatio: number;
    compareOptions: {
        wic: WicImageCompareOptions;
        method: ScreenMethodImageCompareCompareOptions;
    };
    fileName: string;
    folderOptions: ImageCompareFolderOptions;
    isHybridApp: boolean;
    isLandscape: boolean;
    logLevel: LogLevel;
    platformName: string;
    isAndroidNativeWebScreenshot: boolean;
}
export interface WicImageCompareOptions {
    blockOutSideBar: boolean;
    blockOutStatusBar: boolean;
    blockOutToolBar: boolean;
    ignoreAlpha: boolean;
    ignoreAntialiasing: boolean;
    ignoreColors: boolean;
    ignoreLess: boolean;
    ignoreNothing: boolean;
    rawMisMatchPercentage: boolean;
    returnAllCompareData: boolean;
    saveAboveTolerance: number;
}
export interface DefaultImageCompareCompareOptions extends MethodImageCompareCompareOptions {
    blockOut?: RectanglesOutput[];
}
export interface ScreenMethodImageCompareCompareOptions extends DefaultImageCompareCompareOptions, MethodImageCompareCompareOptions {
    blockOutSideBar?: boolean;
    blockOutStatusBar?: boolean;
    blockOutToolBar?: boolean;
}
export interface MethodImageCompareCompareOptions {
    blockOut?: RectanglesOutput[];
    ignoreAlpha?: boolean;
    ignoreAntialiasing?: boolean;
    ignoreColors?: boolean;
    ignoreLess?: boolean;
    ignoreNothing?: boolean;
    rawMisMatchPercentage?: boolean;
    returnAllCompareData?: boolean;
    saveAboveTolerance?: number;
    scaleImagesToSameSize?: boolean;
}
export interface ImageCompareFolderOptions extends Folders {
    autoSaveBaseline: boolean;
    browserName: string;
    deviceName: string;
    isMobile: boolean;
    savePerInstance: boolean;
}
export interface ImageCompareResult {
    fileName: string;
    folders: {
        actual: string;
        baseline: string;
        diff?: string;
    };
    misMatchPercentage: number;
}
export interface CompareOptions {
    ignore: string[];
    output?: {
        ignoredBoxes?: IgnoreBoxes[];
    };
    scaleToSameSize?: boolean;
}
export interface IgnoreBoxes {
    bottom: number;
    right: number;
    left: number;
    top: number;
}
export interface CroppedBase64Image {
    addIOSBezelCorners: boolean;
    base64Image: string;
    deviceName: string;
    devicePixelRatio: number;
    isIos: boolean;
    isLandscape: boolean;
    logLevel: LogLevel;
    rectangles: RectanglesOutput;
    resizeDimensions?: number | ResizeDimensions;
}
export interface RotateBase64ImageOptions {
    base64Image: string;
    degrees: number;
    newHeight: number;
    newWidth: number;
}
